@@ -423,10 +423,12 @@ make_outputs (GnomeRRConfig *config)
 	GnomeRROutputInfo *old = config->priv->outputs[i];
 	GnomeRROutputInfo *new = g_object_new (GNOME_TYPE_RR_OUTPUT_INFO, NULL);
 	*(new->priv) = *(old->priv);
-	if (old->priv->name)
-	    new->priv->name = g_strdup (old->priv->name);
-	if (old->priv->display_name)
-	    new->priv->display_name = g_strdup (old->priv->display_name);
+
+        new->priv->name = g_strdup (old->priv->name);
+        new->priv->display_name = g_strdup (old->priv->display_name);
+        new->priv->vendor = g_strdup (old->priv->vendor);
+        new->priv->product = g_strdup (old->priv->product);
+        new->priv->serial = g_strdup (old->priv->serial);
 
 	if (old->priv->on && !first_on)
 	    first_on = old;
